#!/usr/bin/ruby
# Modus operandi:  Set up some global stuff, like usage message, options, and
# utility methods.  Then act on the options.

USAGE = <<EOS
edtc converts between EDT and standard time.  If no arguments are given, the
current date in EDT format is printed.
USAGE: edtc -[esh] <date>
    -h         prints the current time in both EDT and standard time
    -e <date>  "date" should be a valid EDT date, which will be converted 
               to standard time.  Any missing fields will be filled in with 
               the values for the current date
    -s <date>  "date" should be a valid standard date.  Any missing fields 
               will be filled in with appropriate values for the current 
               date
    <date>     shorthand for "-s <date>"
EOS

require "parsedate"
require "edtdate"
require "getoptlong"

opts = GetoptLong.new(
	[ "--help",			"-h",	GetoptLong::NO_ARGUMENT],
	[ "--edt",			"-e", GetoptLong::REQUIRED_ARGUMENT],
	[ "--standard",	"-s",	GetoptLong::REQUIRED_ARGUMENT]
)

# Parse a standard date (given as a String) to an EDT date and return the
# result.  Errors are not gracefully handled.  Blank values (in the supplied
# string) are filled in with the values from the current time.
def standard_to_edt date
  now = Time.now
  ar = ["year", "month", "day", "hour", "min", "sec", "usec"]
  vals = ParseDate::parsedate date
  7.times do |x|
	 vals[x] = now.send( ar[x] ) unless vals[x]
  end
  vals = vals[0..6]
  vals[6] = 0
  t = Time.local( *vals )
  e = EDTDate.new t.utc
  puts e.to_s
  exit
end

opts.each do |option, arg|
  case option
  when "--standard"
	 standard_to_edt arg
	 exit
  when "--help"
	 puts USAGE
	 exit
  when "--edt"
	 e = EDTDate.new arg
	 puts e.to_time
	 exit
  end
end

if ARGV.size > 0
  standard_to_edt ARGV[0]
else
  puts EDTDate.new
end
